All pastesPublic feed

Public feed

Pastes people chose to make public. Author names hidden.
  • Miscellany

    2057115·text·800 B·2011-05-12 00:41 UTC
    if (horaTermino >= horaInicio)
     {
     durHora = (((horaTermino * 60)+ minTermino) - ((horaInicio * 60) + minInicio))/60;
     }
     else
     {
     durHora = ((((horaTermino + 24)* 60) + m
  • carlosm

    2057106·text·22.2 KB·2011-05-11 23:49 UTC
    !!################################
    !!ALSA Information Script v 0.4.41
    !!################################
    
    !!Script ran on: Wed May 11 19:49:22 EDT 2011
    
    !!Linux Distribution
    !!------------------
    
    Fe
  • Unnamed

    2057104·text·3.5 KB·2011-05-11 23:34 UTC
    # Don't display the copyright notice during startup
    startup_message off
    
    # Remember 5000 lines of history
    defscrollback 5000
    
    # Bind F1 through F7 to switch to window 0 through 6, respectively
  • zanberdo

    2057097·text·128 B·2011-05-11 23:26 UTC
    [Wed May 11 16:25:30 2011].666748 msPostGISLayerIsOpen called.
    [Wed May 11 16:25:30 2011].666795 msPostGISLayerIsOpen called.
  • Anonymous

    2057096·text·2.2 KB·2011-05-11 23:26 UTC
    list list verbs in category 'benchmarks'
    dlls list list verbs in category 'dlls'
    games list list verbs in category 'games'
    settings list list verbs in category
  • jesus loves puppies

    2057092·text·19.6 KB·2011-05-11 23:02 UTC
    I. Introduction
     An often-discussed topic in the contemporary socio-political discourse is the threat of what is described as Radical Islam to the stability of not only the Middle East region, but th
  • Untitled

    2057091·text·380 B·2011-05-11 23:00 UTC
    mail [04:06:56]~
    whodevil>sup-mail
    [Wed May 11 16:07:00 -0700 2011] No 'ncursesw' gem detected. Install it for wide character support.
    Error: the index is locked by another process! User '' on
    hos
  • Anonymous

    2057089·text·112 B·2011-05-11 22:56 UTC
    陽圧式防護服を着用した消防隊員。2003年横浜市緑消防署出初め式にて投稿者撮影。
  • Stuff

    2057086·c·5.9 KB·2011-05-11 22:47 UTC
    __global__ static void SzimulacioKernel(int* ELETTER, int* ELETKOR, int* EHSEG, int* SZAPOR, int* LEPETT)
    {
     int x = blockIdx.x * blockDim.x + threadIdx.x;
     int y = blockIdx.y * blockDim.y + thread
  • Anonymous

    2057085·c·1.4 KB·2011-05-11 22:43 UTC
    void RunKernel(int N)
    {
     // kernel futtatasa N-szer
     for(int i = 0; i < N; i++) {
     dim3 grid((NX*NY-1) / BlockN+1, (NX*NY-1) / BlockN+1);
     dim3 block(BlockN, BlockN);
     LepettNullazKernel<<<gr
  • Something

    2057084·text·1.4 KB·2011-05-11 22:41 UTC
    Region (root) # load oar universal_campus_01_04182011.oar
    23:38:21 - [ARCHIVER]: Loading archive to region Easy Education 1 from universal_campus_01_04182011.oar
    23:38:21 - [ARCHIVER]: Loading OAR w
  • Horizontal map selection

    2057082·diff·12.9 KB·2011-05-11 22:36 UTC
    Index: src/menu/map_selection_box.h
    ===================================================================
    --- src/menu/map_selection_box.h (revision 10091)
    +++ src/menu/map_selection_box.h (working c
  • Anonymous

    2057078·text·9.6 KB·2011-05-11 22:24 UTC
    <html>
    <head>
    <title>Hydraq</title>
    </head>
    
    <body align="justify">
    
    <h1><center>Foreword</center></h1>
    
    <p><i>This report was written by Mathilde CARON, Silviu COCA, Franck ROLAND and Daniel
  • Stuff

    2057074·text·1.1 KB·2011-05-11 22:12 UTC
    main
     mov rbp, rsp
     add rsp, -40
     mov r1, 2
    
    main_loop
     push r1
     call check_for_prime
     
     mov r2, rbp
     mov r3, r1
     mov r4, 4
     mul r3, r4
     sub r2, r3
     m
  • Miscellany

    2057070·ruby·25 B·2011-05-11 22:06 UTC
    @cube[z][y].include?(".")
  • Miscellany

    2057069·ruby·45 B·2011-05-11 22:02 UTC
    (0..x).each {|i|return @cube[z][y][i] == "."}
  • Mine

    2057067·ruby·54 B·2011-05-11 22:00 UTC
    (0..x).each {|i|return false if @cube[z][y][i] != "."}
  • Mine

    2057066·ruby·91 B·2011-05-11 21:58 UTC
    for i in 0..x {
     if @cube[z][y][i] != "."
     return false
     end
     }
  • Unnamed

    2057064·text·30 B·2011-05-11 21:54 UTC
    gotta look deeper than exif :P
  • Anonymous

    2057063·text·12.9 KB·2011-05-11 21:54 UTC
    11 May 20:42 Deleting httpdocs/application/views/register_CriminalRecords/v9/registration.php
    11 May 20:42 Deleting httpdocs/application/views/register_CriminalRecords/v8/registration.php
    11 May 2

older pastes →